/*
Demo of how to talk to a MySQL database from C.
Looks up integer data from the database.

Orion Sky Lawlor, olawlor@acm.org, 2006/04/12 (Public Domain)
*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "config.h"

/*Build and connect to a mysql database.*/
MYSQL *connectSql(void) {
  MYSQL *mysql;

  mysql=(MYSQL *)malloc(sizeof(MYSQL));
  mysql_init(mysql);

  if (!mysql_connect(mysql,MYSQL_HOST,MYSQL_USERID,MYSQL_PASSWD))
  {
    printf("ERROR: Failed to connect to database: %s\n",mysql_error(mysql));
    exit(1);
  }

  if (mysql_select_db(mysql,MYSQL_DB)) {
    printf("ERROR: Failed to select database: %s\n",mysql_error(mysql));
    exit(1);
  }  
  return mysql;
}

/* Print out the message numbers of everything that matches this query */
void queryInts(MYSQL *mysql,const char *query) {
  MYSQL_RES *result;
  MYSQL_ROW row;
  int ret=-1;

  printf("Performing query: \n  %s\n",query);
  mysql_query(mysql,query);
  result = mysql_use_result(mysql);
  if (result==NULL) {
    printf("ERROR: Query failed: %s\n",mysql_error(mysql));	    
    exit(1); /*Query failed*/
  }

  /*Loop over the results:*/
  while ((row = mysql_fetch_row(result)))
  { 
    if (1==sscanf(row[0],"%d",&ret)) {
      printf("Hit record with number %d and %d fields\n",
      	ret,mysql_num_fields(result));
    }
  }
  printf("That's all the records I found.\n");
  mysql_free_result(result);
}

int main(int argc,char *argv[]) {
  MYSQL *mysql;

  mysql=connectSql();

  queryInts(mysql,"SELECT * FROM log WHERE item='crap'");
  
  mysql_close(mysql);

  return 0;
}

